package VMOMI::DistributedVirtualPortgroupMetaTagName;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
